CuteQrCodeView class

Displays a prepared QrCode scaled to parent constraints. 将已准备的 QrCode 按父级约束缩放显示。

Inheritance

Constructors

CuteQrCodeView({required QrCode qrCode, Key? key, bool prepared = true, double? size})
Creates a view for an already-encoded qrCode. 为已编码的 qrCode 创建视图。
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
prepared bool
Whether QrCode.prepare has completed for logos. QrCode.prepare(Logo)是否已完成。
final
qrCode QrCode
QR model to display. 要显示的 QR 模型。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
Fixed square size; omit to use parent constraints. 固定正方形尺寸;省略则使用父级约束。
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited