QrCodeShapeFunction class abstract
Draws individual modules and control patterns onto QrCodeGraphics. 将各模块与控制图案绘制到 QrCodeGraphics。
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beforeRender(
QrCode qrCode, QrCodeGraphics qrCodeGraphics) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renderControlSquare(
int xOffset, int yOffset, QrCodeColorFunction colorFn, QrCodeSquare square, QrCodeGraphics canvas, QrCode qrCode) → void -
renderSquare(
int x, int y, QrCodeColorFunction colorFn, QrCodeSquare square, QrCodeGraphics canvas, QrCode qrCode) → void -
resize(
int newSquareSize) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited